]> mj.ucw.cz Git - leo.git/blobdiff - css.h
css.h: Fixed a wrong type
[leo.git] / css.h
diff --git a/css.h b/css.h
index 9344a639ed168d31a2c82bf99fd621b6d7d6ac1f..1cd76afd93756a598309146f7879e3639cbbc0df 100644 (file)
--- a/css.h
+++ b/css.h
@@ -38,7 +38,7 @@ enum css_object_type {
 
 struct css_path {
   cnode n;
-  enum osm_object_type type;   // Object type or OSM_TYPE_ANY
+  enum css_object_type type;   // Object type or CSS_TYPE_ANY
   clist conditions;            // Attribute conditions
   layer_t layer;               // STYLE_LAYER_xxx or more
   osm_val_t role;